@@ -7,4 +7,12 @@ use Devel::Peek;
 BEGIN { plan tests => 12 };
 use threads;
 
-my $thread3 = threads->create(sub { threads->create(sub {})})->join();
+
+threads->create(sub { 
+    my $self = threads->self();
+    print $self->tid();
+    print "\n";
+})->join();
+
+
+
